package grid;

import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Properties;
import java.util.UUID;

import log.CLog;

import org.infinispan.client.hotrod.RemoteCache;
import org.infinispan.client.hotrod.RemoteCacheManager;

public class GridImplementation implements GridAPI {
	
	RemoteCacheManager manager;
	
	public GridImplementation() {
		Properties props = new Properties();
		props.put( "infinispan.client.hotrod.server_list", System.getProperty( "infinispan.client.hotrod.server_list" ) );
		manager = new RemoteCacheManager(props);				
	}
	
	public UUID getNewUUID() {
		return UUID.randomUUID();
	}

	@SuppressWarnings("rawtypes")
	public void updateSessionAttribute(Object uid, Object attributeName, 
			Object attributeValue, Enumeration attributeNames) {
		try {
			RemoteCache<Object, Object> cache = manager.getCache();			
			HashMap<Object, Object> map = new HashMap<Object, Object>();
			ArrayList<String> listAttributes = new ArrayList<String>();
			while ( attributeNames.hasMoreElements() )
				listAttributes.add( (String) attributeNames.nextElement() );
			map.put( uid + "_" + attributeName, attributeValue );			
			map.put( uid + "_JDG_attributeNames_", listAttributes );
			cache.putAllAsync(map);
		} catch (Exception e) {
			CLog.debug( this, "updateSessionAttribute() error : " + e.toString() );
		}			
	}

	@SuppressWarnings("unchecked")
	public ArrayList<String> getAttributeNames(Object uid) {
		try {
			RemoteCache<Object, Object> cache = manager.getCache();
			return (ArrayList<String>) cache.get( uid + "_JDG_attributeNames_" );			
		} catch (Exception e) {
			CLog.debug( this, "getAttributeNames() error : " + e.toString() );
		}
		return null;
	}

	public Object getAttribute(Object uid) {
		try {
			RemoteCache<Object, Object> cache = manager.getCache();
			return cache.get( uid );			
		} catch (Exception e) {
			CLog.debug( this, "getAttribute() error : " + e.toString() );
		}
		return null;
	}


	
	
}
